@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package XML::BindData;
-$XML::BindData::VERSION = '0.3.1';
+$XML::BindData::VERSION = '0.2';
 use XML::LibXML;
 
 sub bind {
@@ -64,19 +64,12 @@ sub parse_node {
 	}
 
         if ( my $attr_defaults = _strip_attr( $node, 'tmpl-attr-defaults' ) ) {
-            my @attributes
-                = map {
-                [   map { s/\\([:,])/$1/g; $_ } # remove backslash escaping
-                    split qr/(?<!\\):/          # split on non-backslashed colons
-                ]
-                }
-                split qr/(?<!\\),/,           # split on non-backslashed commas
+            my @attributes = map { [ split qr/:/ ] } split qr/,/,
                 $attr_defaults;
 
             foreach (@attributes) {
-                my $value = $node->getAttribute( $_->[0] );
                 $node->setAttribute( $_->[0], $_->[1] )
-                    if ! defined $value || $value eq ''; 
+                    unless defined $node->getAttribute( $_->[0] );
             }
         }
 
@@ -289,14 +282,7 @@ Only show the node if bool is true-ish. Can be negated as C<tmpl-if="!bool">.
 =item tmpl-attr-map="attr-name-one:opt1,attr-name-two:opt2"
 
 Bind the value of 'opt1' into the attribute 'attr-name-one'. Multiple
-attributes can be assigned at a time, separated by commas. Comma and colon
-characters in a default value must be preceded with a single backslash.
-
-=item tmpl-attr-defaults="attr-name-one:default1,attr-name-two:default2"
-
-Bind the value of 'default1' into the attribute 'attr-name-one' if no other
-defined value is supplied. Multiple attributes can be assigned at a time,
-separated by commas.
+attributes can be assigned at a time, separated by commas.
 
 =back
 
